pub enum Error {
IncompleteSequence,
IncompleteUnicode,
InvalidUnicode(u32),
UnknownSequence(char),
ParseIntError(ParseIntError),
}Expand description
Errors which may be returned by the unescaper.
Variants
IncompleteSequence
Error type for a string ending in a backslash without a following escape sequence.
IncompleteUnicode
Error type for a string ending in a Unicode escape sequence (e.g. \x)
without the appropriate amount of hex digits.
InvalidUnicode(u32)
Error type for a Unicode sequence without a valid character code.
UnknownSequence(char)
Error type for unknown escape sequences.
ParseIntError(ParseIntError)
Errors from parsing Unicode hexadecimal numbers.